/*******************************************************************
*
*  Copyright(C) 1998 Videology Imaging Solutions, Inc.
*
*  File Name: gcc-455n.h
*
*  Description: Camera Driver function prototypes
*
* 	All rights reserved.
* 	This material is confidential and may not be reproduced by any means.
*
*  Revision Log:
*  $Log:   $
*
*
*
*                                                           
*******************************************************************/

#if !defined(__gcc_455n_H__)
#define __gcc_455n_H__

#include <windows.h>

#ifdef _WIN32
	#ifdef _DLL
	#define EXPORT __declspec(dllexport)
	#else
	#define EXPORT __declspec(dllimport)
	#endif
#else 
#define EXPORT _export
#endif


// Camera Capability Constants
#define CAMERA_CAN_ZOOM  					0x0001
#define CAMERA_CAN_FOCUS 					0x0002
#define CAMERA_CAN_ADJUST_WHITE_BALANCE 	0x0004
#define CAMERA_CAN_SHOW_MENU 				0x0008
#define CAMERA_HAS_SHUTTER_SPEED 			0x0010
#define CAMERA_HAS_IRIS_CONTROL				0x0020
#define CAMERA_HAS_AGC						0x0040
#define CAMERA_HAS_BRIGHTNESS				0x0080

// GLOBALS
extern HINSTANCE hModuleInstance; 
#ifdef _WIN32
extern HANDLE idComDev;			// communications handle
#else
extern int idComDev;			// communications handle
#endif
                                              
//PROTOTYPES
int EXPORT WINAPI 	GetCameraCabilities(void);
BOOL EXPORT WINAPI 	OpenCamera(int port);
void EXPORT WINAPI 	CloseCamera(void);
BOOL EXPORT WINAPI 	ZoomIn(BOOL stop,int delay);
BOOL EXPORT WINAPI ZoomOut(BOOL stop,int delay);
BOOL EXPORT WINAPI StopAction(void);
BOOL EXPORT WINAPI FocusNear(BOOL stop,int delay);
BOOL EXPORT WINAPI FocusFar(BOOL stop,int delay);
BOOL EXPORT WINAPI FocusAuto(void);
BOOL EXPORT WINAPI FocusManual(void);
BOOL EXPORT WINAPI MenuOn(void);
BOOL EXPORT WINAPI MenuOff(void);
BOOL EXPORT WINAPI CameraReset(void);
BOOL EXPORT WINAPI BlueDown(BOOL stop,int delay);
BOOL EXPORT WINAPI BlueUp(BOOL stop,int delay);
BOOL EXPORT WINAPI RedDown(BOOL stop,int delay);
BOOL EXPORT WINAPI RedUp(BOOL stop,int delay);
BOOL EXPORT WINAPI ManualExposure(void);
BOOL EXPORT WINAPI AutoExposure(void);
BOOL EXPORT WINAPI AutoWhiteBalance(void);
BOOL EXPORT WINAPI ManualWhiteBalance(void);
BOOL EXPORT WINAPI LiveMode(void);
BOOL EXPORT WINAPI FlashMode(BOOL wait);
BOOL EXPORT WINAPI ShutterDown(BOOL stop,int delay);
BOOL EXPORT WINAPI ShutterUp(BOOL stop,int delay);
BOOL EXPORT WINAPI IrisDown(BOOL stop,int delay);
BOOL EXPORT WINAPI IrisUp(BOOL stop,int delay);
BOOL EXPORT WINAPI AGCDown(BOOL stop,int delay);
BOOL EXPORT WINAPI AGCUp(BOOL stop,int delay);
BOOL EXPORT WINAPI BrightnessDown(BOOL stop,int delay);
BOOL EXPORT WINAPI BrightnessUp(BOOL stop,int delay);
BOOL EXPORT WINAPI ODSOff(void);
BOOL EXPORT WINAPI IsCameraOpen(void);
int  EXPORT WINAPI GetCameraPort(void);	// 1-base comm port number
BOOL EXPORT WINAPI OpenCommPort(void);
void EXPORT WINAPI CloseCommPort(void);
BOOL EXPORT WINAPI IsMenuShowing(void);
void EXPORT WINAPI openControlDialog(void);
void EXPORT WINAPI closeControlDialog(void);
void EXPORT WINAPI setWantControlDialogFlag(BOOL flag);
BOOL EXPORT WINAPI getWantControlDialogFlag(void);




// Camera Communications constants
#define GMC_COMMAND_LENGTH				5	// not including checksum
#define GMC_RESPONSE_LENGTH			9	// includes checksum
#define GMC_CAMERA_ID					0
#define GMC_START							0xc5
#define GMC_KEYACTION					0x5f
#define GMC_CONTROL_ACTION				0xaa
#define ZOOMIN								0x02
#define ZOOMOUT							0x04
#define STOPACTION						0x0c
#define FOCUSNEAR							0x09
#define FOCUSFAR							0x08
#define FOCUSMANUAL						0x59
#define FOCUSAUTO							0x58
#define MENUTOGGLE						0x25
#define CAMERARESET						0x4f
#define BLUEDOWN							0x4b
#define BLUEUP								0x4a
#define REDDOWN							0x49
#define REDUP								0x48
#define EXPOSUREMODE						0x60
#define MANUALEXPOSURE					0x04
#define AUTOEXPOSURE						0x00
#define WHITEBALANCEMODE				0x65
#define AUTOWHITEBALANCE				0x00
#define SPECIALWHITEBALANCE			0x01
#define SHUTTERUP							0x40
#define SHUTTERDOWN						0x41
#define IRISUP								0x42
#define IRISDOWN							0x43
#define AGCUP								0x44
#define AGCDOWN							0x45
#define BRIGHTNESSUP						0x46
#define BRIGHTNESSDOWN					0x47
#define ODSOFF								0x24

		// macros
#define KEYACTION(C)	commandBuffer[0] = GMC_START; \
							commandBuffer[1] = GMC_KEYACTION; \
							commandBuffer[2] = C; \
							commandBuffer[3] = 0; \
							commandBuffer[4] = GMC_CAMERA_ID
#define CONTROLACTION(C1,C2)	commandBuffer[0] = GMC_START; \
							commandBuffer[1] = GMC_CONTROL_ACTION; \
							commandBuffer[2] = C1; \
							commandBuffer[3] = C2; \
							commandBuffer[4] = GMC_CAMERA_ID

#endif
