/*******************************************************************
*
*  Copyright(C) 1999 Ashdown Technologies, Inc.
*
*  File Name: ccd-z14.h
*
*  Description: Chugai Camera Driver function prototypes
*
* 	All rights reserved.
* 	This material is confidential and may not be reproduced by any means.
*
*  Revision Log:
*  $Log:   $
*
*
*
*                                                           
*******************************************************************/

#if !defined(__gcc_455n_H__)
#define __gcc_455n_H__

#include <windows.h>
#ifdef _WIN32
	#ifdef _DLL
	#define EXPORT __declspec(dllexport)
	#else
	#define EXPORT __declspec(dllimport)
	#endif
#else 
#define EXPORT _export
#endif


// Camera Capability Constants
#define CAMERA_CAN_ZOOM  					0x0001
#define CAMERA_CAN_FOCUS 					0x0002
#define CAMERA_CAN_ADJUST_WHITE_BALANCE 	0x0004
#define CAMERA_CAN_SHOW_MENU 				0x0000
#define CAMERA_HAS_SHUTTER_SPEED 			0x0010
#define CAMERA_HAS_IRIS_CONTROL				0x0020
#define CAMERA_HAS_AGC						0x0040
#define CAMERA_HAS_BRIGHTNESS				0x0080

// GLOBALS
extern HINSTANCE hModuleInstance; 
#ifdef _WIN32
extern HANDLE idComDev;			// communications handle
#else
extern int idComDev;			// communications handle
#endif
                                              
//PROTOTYPES
int  EXPORT WINAPI GetCameraCabilities(void);
BOOL EXPORT WINAPI OpenCamera(int port);
void EXPORT WINAPI CloseCamera(void);
BOOL EXPORT WINAPI ZoomIn(BOOL stop,int delay);
BOOL EXPORT WINAPI ZoomOut(BOOL stop,int delay);
BOOL EXPORT WINAPI StopAction(void);
BOOL EXPORT WINAPI FocusNear(BOOL stop,int delay);
BOOL EXPORT WINAPI FocusFar(BOOL stop,int delay);
BOOL EXPORT WINAPI FocusAuto(void);
BOOL EXPORT WINAPI FocusManual(void);
BOOL EXPORT WINAPI MenuOn(void);
BOOL EXPORT WINAPI MenuOff(void);
BOOL EXPORT WINAPI CameraReset(void);
BOOL EXPORT WINAPI BlueDown(BOOL stop,int delay);
BOOL EXPORT WINAPI BlueUp(BOOL stop,int delay);
BOOL EXPORT WINAPI RedDown(BOOL stop,int delay);
BOOL EXPORT WINAPI RedUp(BOOL stop,int delay);
BOOL EXPORT WINAPI ManualExposure(void);
BOOL EXPORT WINAPI AutoExposure(void);
BOOL EXPORT WINAPI AutoWhiteBalance(void);
BOOL EXPORT WINAPI ManualWhiteBalance(void);
BOOL EXPORT WINAPI LiveMode(void);
BOOL EXPORT WINAPI FlashMode(BOOL wait);
BOOL EXPORT WINAPI ShutterDown(BOOL stop,int delay);
BOOL EXPORT WINAPI ShutterUp(BOOL stop,int delay);
BOOL EXPORT WINAPI IrisDown(BOOL stop,int delay);
BOOL EXPORT WINAPI IrisUp(BOOL stop,int delay);
BOOL EXPORT WINAPI AGCDown(BOOL stop,int delay);
BOOL EXPORT WINAPI AGCUp(BOOL stop,int delay);
BOOL EXPORT WINAPI BrightnessDown(BOOL stop,int delay);
BOOL EXPORT WINAPI BrightnessUp(BOOL stop,int delay);
BOOL EXPORT WINAPI ODSOff(void);
BOOL EXPORT WINAPI IsCameraOpen(void);
int  EXPORT WINAPI GetCameraPort(void);	// 1-base comm port number
BOOL EXPORT WINAPI OpenCommPort(void);
void EXPORT WINAPI CloseCommPort(void);
BOOL EXPORT WINAPI IsMenuShowing(void);
void EXPORT WINAPI openControlDialog(void);
void EXPORT WINAPI closeControlDialog(void);
void EXPORT WINAPI setWantControlDialogFlag(BOOL flag);
BOOL EXPORT WINAPI getWantControlDialogFlag(void);




// Camera Communications constants
//#define GMC_COMMAND_LENGTH				5	// not including checksum
//#define GMC_RESPONSE_LENGTH				9	// includes checksum
#define GMC_CAMERA_ID					0
//#define GMC_START							0xc5
//#define GMC_KEYACTION					0x5f
//#define GMC_CONTROL_ACTION				0xaa
#define ZOOMIN							"ZMT"
#define ZOOMOUT							"ZMW"
#define ZOOMSTOP						"ZMS"
//#define STOPACTION						0x0c
#define FOCUSNEAR						"FCN"
#define FOCUSFAR						"FCF"
#define FOCUSSTOP						"FCS"
//#define FOCUSMANUAL						0x59
#define FOCUSAUTO						"FCA"
//#define MENUTOGGLE						0x25
#define CAMERARESET						"MP"
#define AUTOWHITEBALANCE				"WBA"
#define SPECIALWHITEBALANCE				"WBM"
#define BLUEDOWN						"WBBD"
#define BLUEUP							"WBBU"
#define BLUEABSOLUTE					"WBB%d"     // 0-255
#define REDDOWN							"WBRD"
#define REDUP							"WBRU"
#define REDABSOLUTE						"WBR%d"     // 0-255
//#define EXPOSUREMODE						0x60
#define MANUALEXPOSURE					"IRM"
#define AUTOEXPOSURE					"IRA"
#define IRISUP							"IRU"
#define IRISDOWN						"IRD"
#define IRISABSOLUTE					"IRM%d"     // +/-30
//#define WHITEBALANCEMODE				0x65
#define SHUTTERUP						"SSU"
#define SHUTTERDOWN						"SSD"
#define SHUTTERABSOLUTE					"SS%d"      // 0-7
#define AGCAUTO							"GNA"
#define AGCMANUAL						"GNM"
#define AGCUP							"GNU"
#define AGCDOWN							"GND" 
#define AGCABSOLUTE						"GNM%d"		// +/-30
//#define BRIGHTNESSUP						0x46
//#define BRIGHTNESSDOWN					0x47
#define ODSOFF							"DS0"
#define SHOW_FOCUS						"DS1"
#define SHOW_IRIS						"DS2"
#define SHOW_GAIN						"DS3"
#define SHOW_BACKLIGHT					"DS4"
#define SHOW_SHUTTER					"DS5"
#define SHOW_DETAIL						"DS6"
#define SHOW_WHITEBALANCE				"DS7"
#define SHOW_COLOR						"DS8"
#define SHOW_SUBMENU					"DS9"
#define LENS_CONTROL					"LD%03X%03X"


////////////// Camera Command Responses ///////////////////
#define RC_ZOOM							"EX10"
#define RC_FOCUS                        "EX11"
#define RC_WHITEBALANCE					"EX03"
#define RC_SHUTTERSPEED					"EX05"
#define RC_IRIS							"EX07"
#define RC_GAIN							"EX08"
#define RC_ODS							"EX20"
#define RC_RESET						"EX23"
#define RC_LENSCONTROL					"EX22"
#define RC_INQUIRY						""

////////////// CAMERA Inquiry Commands ///////////////////

#define GET_ZOOM						"ST0"
#define GET_FOCUS						"ST1"
#define GET_PRESET						"ST2"
#define GET_AGC_IRIS					"ST3"
#define GET_BACK_LIGHT					"ST4"
#define GET_SHUTTERSPEED				"ST5"
#define GET_DETAIL						"ST6"
#define GET_COLOR						"ST7"
#define GET_WHITEBALANCE				"ST8"
#define GET_AUTOFOCUS					"ST9"
#define GET_AUTOWHITEBALANCESPEED		"STA"
#define GET_PLL_SHIFT					"STB"
#define GET_BACKUP						"STG" 
#define GET_BRIGHT						"STI"

//////////////////////////////////////////////////////////
////////////// COMMAND IDs ///////////////////////////////

#define CMD_ZOOMIN                       0
#define CMD_ZOOMOUT                      1
#define CMD_ZOOMSTOP                     2
#define CMD_FOCUSNEAR                    3
#define CMD_FOCUSFAR                     4
#define CMD_FOCUSSTOP                    5
#define CMD_FOCUSAUTO                    6
#define CMD_CAMERARESET                  7
#define CMD_BLUEUP                       8
#define CMD_BLUEDOWN                     9
#define CMD_REDUP                        10
#define CMD_REDDOWN                      11
#define CMD_MANUALEXPOSURE               12
#define CMD_AUTOEXPOSURE                 13
#define CMD_AUTOWHITEBALANCE             14
#define CMD_SPECIALWHITEBALANCE          15
#define CMD_SHUTTERUP                    16
#define CMD_SHUTTERDOWN                  17
#define CMD_IRISUP                       18
#define CMD_IRISDOWN                     19
#define CMD_AGCAUTO                      20
#define CMD_AGCMANUAL                    21
#define CMD_AGCUP                        22
#define CMD_AGCDOWN                      23
#define CMD_ODSOFF                       24
#define CMD_GET_ZOOM                     25
#define CMD_GET_FOCUS                    26
#define CMD_GET_PRESET                   27
#define CMD_GET_AGC_IRIS                 28
#define CMD_GET_BACK_LIGHT               29
#define CMD_GET_SHUTTERSPEED             30
#define CMD_GET_DETAIL                   31
#define CMD_GET_COLOR                    32
#define CMD_GET_WHITEBALANCE             33
#define CMD_GET_AUTOFOCUS                34
#define CMD_GET_AUTOWHITEBALANCESPEED    35
#define CMD_GET_PLL_SHIFT                36
#define CMD_GET_BACKUP                   37
#define CMD_GET_BRIGHT                   38
#define CMD_BLUEABSOLUTE                 39
#define CMD_REDABSOLUTE                  40
#define CMD_IRISABSOLUTE                 41
#define CMD_SHUTTERABSOLUTE              42
#define CMD_AGCABSOLUTE                  43
#define CMD_SHOW_FOCUS					 44
#define CMD_SHOW_IRIS					 45
#define CMD_SHOW_GAIN					 46
#define CMD_SHOW_BACKLIGHT				 47
#define CMD_SHOW_SHUTTER				 48
#define CMD_SHOW_DETAIL					 49
#define CMD_SHOW_WHITEBALANCE			 50
#define CMD_SHOW_COLOR					 51
#define CMD_SHOW_SUBMENU				 52
#define CMD_SET_LENS					 53
                                         
#define NUMBEROFCOMMANDS				 54

typedef struct
		{
		char *command;				// command to send                   
		int controlValueCount;      // number of control values
		int	controlValue[2];		// array of control values if command needs them (maximum of 2)
		char *response;				// expected good response
		unsigned returnValues;		// number of return values command returns
		int *values;				// array of returned values
		BOOL signedValues;			// true if returned values are signed hex
		} COMMAND;


#endif
